{
  description = "OpenAlex client";

  inputs = {
    flake-utils.url = "github:numtide/flake-utils";
    haskell-nix = {
      url = "github:input-output-hk/haskell.nix";
    };
    nixpkgs.follows = "haskell-nix/nixpkgs-unstable";
  };

  outputs = { self, nixpkgs, flake-utils, haskell-nix }:
    flake-utils.lib.eachDefaultSystem (system:
      let
        compiler-nix-name = "ghc96";
        
        pkgs = import nixpkgs { 
          inherit system;
          
          config = haskell-nix.config;

          overlays = [
            haskell-nix.overlay
            (final: prev: {
              # This overlay adds our project to the package set
              openalex-hs =
                final.haskell-nix.project' {
                  inherit compiler-nix-name;
                  
                  src = ./.;
                };
            })
          ];
        };
        
        flake = pkgs.openalex-hs.flake {};
      in
      {
        # Built by `nix build`
        packages = flake.packages // {
          default = flake.packages."openalex:lib:openalex";
        };
        
        # Run by `nix run`
        apps = flake.apps;
        
        # Used by `nix develop`
        devShells = flake.devShells // {
          default = flake.devShells.default.overrideAttrs (oldAttrs: rec {
            buildInputs = oldAttrs.buildInputs ++ [
              # Add additional development tools here
              pkgs.cabal-install
              pkgs.hlint
              pkgs.haskell-language-server
            ];
          });
        };
        
        # Used by `nix flake check`
        checks = flake.checks;
      });

  # Add the nixConfig section for binary caches
  nixConfig = {
    extra-substituters = [
      "https://cache.iog.io"
    ];
    extra-trusted-public-keys = [
      "hydra.iohk.io:f/Ea+s+dFdN+3Y/G+FDgSq+a5NEWhJGzdjvKNGv0/EQ="
    ];
    allow-import-from-derivation = true;
  };
}
